@@ -32,15 +32,25 @@ class DataFrameToolkit:
         """
         b_buf = io.BytesIO(b_data)
 
-        date_parser = lambda x: datetime.datetime.strptime(x, "%Y-%m-%d-%H-%M-%S-%f")
         df = pandas.read_csv(b_buf,
-                             index_col='Timestamp',
-                             parse_dates=['Timestamp'],
-                             date_parser=date_parser,
                              sep=",",
                              decimal=".",
                              encoding="utf-8")
 
+        # detect timestamp column
+        if "timestamp" in df.columns:
+            df = df.rename(columns={'timestamp': 'Timestamp'})
+        if "Timestamp" not in df.columns:
+            raise ValueError('Cannot read dataframe as no Timestamp columns exists.')
+
+        # detect timestamp type
+        if df['Timestamp'].dtypes == 'int64':
+            df['Timestamp'] = pandas.to_datetime(df['Timestamp'], unit="ms")
+        elif df['Timestamp'].dtypes == 'object':
+            df['Timestamp'] = df['Timestamp'].apply(lambda _: datetime.datetime.strptime(_, "%Y-%m-%d-%H-%M-%S-%f"))
+
+        df = df.set_index('Timestamp')
+
         return df
 
     @classmethod
